==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Вилучити все</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Центр сповіщень</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Вилучити все</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Відшпилити</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Пришпилити</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Параметри сповіщень</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Щойно</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 хвилин тому</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 годину тому</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 годин тому</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Вчора</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Вилучити все</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Центр сповіщень</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Вилучити все</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Відшпилити</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Пришпилити</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Параметри сповіщень</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Щойно</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 хвилин тому</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 годину тому</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 годин тому</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Вчора</translation>
    </message>
</context>
</TS>
